@@ -1,7 +1,7 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 4.7 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: autogen.h,v 4.8 2005/09/10 18:37:50 bkorb Exp $
  *  Global header file for AutoGen
  */
 
@@ -263,13 +263,6 @@ struct fpStack {
     tCC*        pzOutName;
 };
 
-typedef struct {
-    tCC*        pzFileName;
-    int         fd;
-    size_t      size;
-    void*       pData;
-} tMapInfo;
-
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  FOR loop processing state
