@@ -1,7 +1,7 @@
 /*  -*- Mode: C -*-
  *
  *  expFormat.c
- *  $Id: expFormat.c,v 4.2 2005/01/24 00:00:32 bkorb Exp $
+ *  $Id: expFormat.c,v 4.5 2005/09/10 18:36:20 bkorb Exp $
  *  This module implements formatting expression functions.
  */
 
@@ -21,15 +21,16 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 static const char zGpl[] =
 "%2$s%1$s is free software.\n%2$s\n"
 "%2$sYou may redistribute it and/or modify it under the terms of the\n"
 "%2$sGNU General Public License, as published by the Free Software\n"
-"%2$sFoundation; either version 2, or (at your option) any later version.\n"
+"%2$sFoundation; either version 2 of the License, or (at your option)\n"
+"%2$sany later version.\n"
 "%2$s\n"
 "%2$s%1$s is distributed in the hope that it will be useful,\n"
 "%2$sbut WITHOUT ANY WARRANTY; without even the implied warranty of\n"
@@ -37,10 +38,10 @@ static const char zGpl[] =
 "%2$sSee the GNU General Public License for more details.\n"
 "%2$s\n"
 "%2$sYou should have received a copy of the GNU General Public License\n"
-"%2$salong with %1$s.  See the file \"COPYING\".  If not,\n"
-"%2$swrite to:  The Free Software Foundation, Inc.,\n"
-"%2$s           59 Temple Place - Suite 330,\n"
-"%2$s           Boston,  MA  02111-1307, USA.";
+"%2$salong with %1$s.  If not, write to:\n"
+"%2$s\tThe Free Software Foundation, Inc.,\n"
+"%2$s\t51 Franklin Street, Fifth Floor\n"
+"%2$s\tBoston, MA  02110-1301, USA.";
 
 static const char zLgpl[] =
 "%2$s%1$s is free software; you can redistribute it and/or\n"
@@ -54,10 +55,10 @@ static const char zLgpl[] =
 "%2$sLesser General Public License for more details.\n"
 "%2$s\n"
 "%2$sYou should have received a copy of the GNU Lesser General Public\n"
-"%2$sLicense along with %1$s; if not, write to:\n"
-"%2$s           The Free Software Foundation, Inc.,\n"
-"%2$s           59 Temple Place - Suite 330,\n"
-"%2$s           Boston,  MA  02111-1307, USA.";
+"%2$sLicense along with %1$s.  If not, write to:\n"
+"%2$s\tThe Free Software Foundation, Inc.,\n"
+"%2$s\t51 Franklin Street, Fifth Floor\n"
+"%2$s\tBoston, MA  02110-1301, USA.";
 
 static const char zBsd[] =
 "%2$s%1$s is free software copyrighted by %3$s.\n%2$s\n"
@@ -439,7 +440,7 @@ SCM
 ag_scm_bsd( SCM prog_name, SCM owner, SCM prefix )
 {
     char*   pzPfx   = ag_scm2zchars( prefix, "GPL line prefix" );
-    char*   pzPrg  = ag_scm2zchars( prog_name, "program name" );
+    char*   pzPrg   = ag_scm2zchars( prog_name, "program name" );
     char*   pzOwner = ag_scm2zchars( owner, "owner" );
     char*   pzRes;
     SCM     res;
@@ -498,7 +499,10 @@ ag_scm_license( SCM license, SCM prog_name, SCM owner, SCM prefix )
     char*   pzPfx   = ag_scm2zchars( prefix, "GPL line prefix" );
     char*   pzPrg  = ag_scm2zchars( prog_name, "program name" );
     char*   pzOwner = ag_scm2zchars( owner, "owner" );
-    static tMapInfo mi = { NULL, 0, 0, NULL };
+    static struct {
+        tCC*    pzFN;
+        tmap_info_t mi;
+    } lic = { NULL, { NULL, 0, 0, 0, 0, 0, 0, 0 }};
 
     char*     pzRes;
     SCM       res;
@@ -507,38 +511,39 @@ ag_scm_license( SCM license, SCM prog_name, SCM owner, SCM prefix )
         return SCM_UNDEFINED;
 
     {
+        tSCC*  apzSfx[] = { "lic", NULL };
+        static char zRealFile[ MAXPATHLEN ];
         char* pzLicense = ag_scm2zchars( license, "license file name" );
 
         /*
-         *  Set the current file name.
-         *  If it changes, then unmap the old data
+         *  Find the template file somewhere
          */
-        if (mi.pzFileName == NULL)
-            mi.pzFileName = pzLicense;
+        if (! SUCCESSFUL( findFile( pzLicense, zRealFile, apzSfx )))
+            AG_ABEND( aprf( zCannot, ENOENT, "map license file", pzLicense,
+                            strerror( ENOENT )));
 
-        else if (strcmp( mi.pzFileName, pzLicense ) != 0) {
-            munmap( mi.pData, mi.size );
-            close( mi.fd );
-            mi.pData = NULL;
-            AGFREE( (void*)mi.pzFileName );
-            mi.pzFileName = pzLicense;
+        if ((lic.pzFN != NULL) && (strcmp( zRealFile, lic.pzFN ) != 0)) {
+            text_munmap( &lic.mi );
+            AGFREE( (void*)lic.pzFN );
+            lic.pzFN = NULL;
+        }
+
+        if (lic.pzFN == NULL) {
+            if (text_mmap(zRealFile, PROT_READ|PROT_WRITE, MAP_PRIVATE, &lic.mi)
+                == MAP_FAILED)
+                AG_ABEND( aprf( "Could not open license file '%s'", pzLicense));
+
+            AGDUPSTR( lic.pzFN, zRealFile, "license file name" );
         }
     }
 
     /*
-     *  Make sure the data are loaded and trim any white space.
-     *  If the data pointer is NULL, then we have put a Guile-allocated
-     *  string pointer into mi.pzFileName.  "mapDataFile" will insert
-     *  an AGSTRDUP-ed string there.
+     *  Trim trailing white space.
      */
-    if (mi.pData == NULL) {
-        char* pz;
-        tSCC*  apzSfx[] = { "lic", NULL };
-
-        mapDataFile( mi.pzFileName, &mi, apzSfx );
-
-        pz = (char*)mi.pData + mi.size - 1;
-        while (isspace( pz[-1] )) pz--;
+    {
+        char* pz = (char*)lic.mi.txt_data + lic.mi.txt_size;
+        while (isspace( pz[-1] ) && (pz > (char*)lic.mi.txt_data))
+            pz--;
         *pz = NUL;
     }
 
@@ -559,7 +564,7 @@ ag_scm_license( SCM license, SCM prog_name, SCM owner, SCM prefix )
     /*
      *  Reformat the string with the given arguments
      */
-    pzRes = aprf( (char*)mi.pData, pzPrg, pzOwner );
+    pzRes = aprf( (char*)lic.mi.txt_data, pzPrg, pzOwner );
     {
         int     pfx_size = strlen( pzPfx );
         char*   pzScan   = pzRes;
