@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Thu Jul 28 16:19:16 PDT 2005
+ * Generated Sat Oct  8 11:13:44 PDT 2005
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD
@@ -119,15 +119,6 @@ findPlace( char* name, tCC* pzIndex );
 LOCAL void
 readDefines( void );
 
-/*
- *  Extracted from expExtract.c
- */
-/*
- *  Extracted from expFormat.c
- */
-/*
- *  Extracted from expGperf.c
- */
 /*
  *  Extracted from expGuile.c
  */
@@ -137,9 +128,6 @@ gh_type_e( SCM typ );
 LOCAL SCM
 ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line );
 
-/*
- *  Extracted from expMake.c
- */
 /*
  *  Extracted from expOutput.c
  */
@@ -152,18 +140,6 @@ removeWriteAccess( int fd );
 LOCAL SCM
 run_printf( char* pzFmt, int len, SCM alist );
 
-/*
- *  Extracted from expState.c
- */
-/*
- *  Extracted from expString.c
- */
-/*
- *  Extracted from fmemopen.c
- */
-/*
- *  Extracted from funcCase.c
- */
 /*
  *  Extracted from funcDef.c
  */
@@ -182,15 +158,6 @@ evalExpression( ag_bool* pMustFree );
 LOCAL SCM
 eval( const char* pzExpr );
 
-/*
- *  Extracted from funcFor.c
- */
-/*
- *  Extracted from funcIf.c
- */
-/*
- *  Extracted from functions.c
- */
 /*
  *  Extracted from loadPseudo.c
  */
@@ -200,9 +167,6 @@ doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo );
 LOCAL tCC*
 loadPseudoMacro( tCC* pzData, tCC* pzFileName );
 
-/*
- *  Extracted from opts.c
- */
 /*
  *  Extracted from tpLoad.c
  */
@@ -215,9 +179,6 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList );
 LOCAL tTemplate*
 templateFixup( tTemplate* pTList, size_t ttlSize );
 
-LOCAL void
-mapDataFile( tCC* pzFileName, tMapInfo* pMapInfo, tCC** papSuffixList );
-
 LOCAL tTemplate*
 loadTemplate( tCC* pzFileName );
 
