@@ -1,7 +1,7 @@
 
 /*
- *  $Id: autoopts.c,v 4.9 2005/06/07 22:26:44 bkorb Exp $
- *  Time-stamp:      "2005-03-13 08:39:23 bkorb"
+ *  $Id: autoopts.c,v 4.12 2005/10/02 17:38:46 bkorb Exp $
+ *  Time-stamp:      "2005-10-02 10:37:29 bkorb"
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -56,6 +56,16 @@
 #  include "compat/pathfind.c"
 #endif
 
+#ifndef HAVE_LIBSNPRINTFV
+# ifndef HAVE_SNPRINTF
+#   include "compat/snprintf.c"
+# endif
+
+# ifndef HAVE_STRDUP
+#   include "compat/strdup.c"
+# endif
+#endif
+
 static const char zNil[] = "";
 
 #define SKIP_RC_FILES(po) \
